<?php
session_start(); // Inizializza la sessione

// Funzione per validare e sanitizzare i nomi
function validaNome($nome) {
    $nome = trim($nome); // Rimuovi spazi bianchi
    if (strlen($nome) > 20 || strlen($nome) === 0) { // Verifica la lunghezza e se è vuoto
        return false;
    }
    return htmlspecialchars($nome, ENT_QUOTES, 'UTF-8'); // Prevenzione XSS
}

// Verifica se il form è stato inviato
if ($_SERVER['REQUEST_METHOD'] === 'POST' && !empty($_POST['nomi'])) {
    // Ottieni i nomi inseriti e trasformali in un array
    $nomi = explode(',', $_POST['nomi']);
    
    // Verifica se il numero di nomi è superiore a 30
    if (count($nomi) > 30) {
        echo "<p style='color: red;'>Errore: Puoi inserire al massimo 30 nomi.</p>";
    } else {
        // Rimuovi eventuali spazi bianchi e sanitizza i nomi
        $nomi = array_map('validaNome', $nomi);

        // Filtra eventuali nomi non validi (es. troppo lunghi)
        $nomi = array_filter($nomi, function($nome) {
            return $nome !== false && $nome !== ''; // Escludi i falsi e i vuoti
        });

        // Rimuovi eventuali duplicati
        $nomi = array_unique($nomi);

        // Mescola l'array
        shuffle($nomi);

        // Salva l'assegnazione nella sessione
        $_SESSION['assegnazione'] = $nomi;
    }
}

// Recupera l'assegnazione dei posti dalla sessione, se esiste
$assegnazione = isset($_SESSION['assegnazione']) ? $_SESSION['assegnazione'] : null;
?>

<!DOCTYPE html>
<html lang="it">
<head>
<meta charset="UTF-8">
<title>Assegnazione Posti Randomica</title>
</head>
<body>

<!-- Form per l'inserimento dei nomi -->
<form action="" method="post">
    Inserisci i nomi (separati da virgola, max 20 caratteri ciascuno, max 30 nomi): <input type="text" name="nomi" required>
    <input type="submit" value="Assegna Posti">
</form>

<?php if ($assegnazione): ?>
    <!-- Mostra l'assegnazione dei posti se esiste -->
    <h2>Assegnazione Posti a Sedere</h2>
    <ul>
        <?php foreach ($assegnazione as $indice => $nome): ?>
            <li>Posto <?php echo $indice + 1; ?>: <?php echo $nome; ?></li>
        <?php endforeach; ?>
    </ul>
<?php endif; ?>

</body>
</html>
