<?php
// Definisce il doctype e l'inizio dell'HTML
echo '<!DOCTYPE html>
<html lang="it">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Generatore di Turni</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 20px;
            /* background-color: #f4f4f4; */
        }
        .title {
            font-size: 24px;
            margin-bottom: 20px;
        }
        .subtitle {
            font-size: 20px;
            font-weight: bold;
            margin-top: 20px;
        }
        .result {
            margin-top: 20px;
        }
    </style>
</head>
<body>

<div class="title">Clicca il pulsante per generare i turni</div>
<form method="POST">
    <button class="fixed-button" type="submit">Genera turni</button><br><br>
    <label for="numero_giocatori">Seleziona il numero di giocatori (da 4 a 30):</label>
    <select name="numero_giocatori" id="numero_giocatori" required>';

// Genera le opzioni per il numero di giocatori
for ($i = 4; $i <= 30; $i++) {
    $selected = (isset($_POST['numero_giocatori']) && $_POST['numero_giocatori'] == $i) ? 'selected' : '';
    echo "<option value=\"$i\" $selected>$i</option>";
}

// Continuazione del form
echo '</select>
</form>';

// Verifica se il form è stato inviato
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Protezione contro attacchi XSS e SQL Injection
    $numero_giocatori = filter_input(INPUT_POST, 'numero_giocatori', FILTER_VALIDATE_INT, [
        'options' => [
            'min_range' => 4,
            'max_range' => 30,
        ]
    ]);

    if ($numero_giocatori === false) {
        echo "<p class='result'>Il numero di giocatori deve essere un numero intero tra 4 e 30.</p>";
    } else {
        echo "<div class='result'>";
        echo "<div class='subtitle'>Turni per $numero_giocatori giocatori:</div>";

        // Funzione per generare i turni
        function generaTurni($numero_giocatori) {
            $turni = [];
            $giocatori = range(1, $numero_giocatori);

            // Se dispari, aggiungi un giocatore "BYE"
            if ($numero_giocatori % 2 != 0) {
                $giocatori[] = 'BYE';
                $numero_giocatori++;
            }

            for ($round = 1; $round < $numero_giocatori; $round++) {
                $turno = [];
                for ($i = 0; $i < $numero_giocatori / 2; $i++) {
                    $giocatore1 = $giocatori[$i];
                    $giocatore2 = $giocatori[$numero_giocatori - 1 - $i];

                    if ($giocatore1 != 'BYE' && $giocatore2 != 'BYE') {
                        $turno[] = "Giocatore $giocatore1 vs Giocatore $giocatore2";
                    }
                }
                $turni[$round] = $turno;

                // Ruota i giocatori
                $ultimo = array_pop($giocatori);
                array_splice($giocatori, 1, 0, $ultimo);
            }

            return $turni;
        }

        // Generazione dei turni
        $turni = generaTurni($numero_giocatori);

        // Stampa i turni
        foreach ($turni as $num_turno => $matches) {
            echo "<div class='subtitle'>Turno $num_turno:</div><ul>";
            foreach ($matches as $match) {
                echo "<li>$match</li>";
            }
            echo "</ul>";
        }

        echo "</div>";
    }
}

// Chiusura del body
echo '</body>
</html>';
?>
